#!/bin/sh
#
# $Id: make-postfix.spec,v 1.29 2001/06/08 16:24:43 sjmudd Exp $
#
# Script to create the postfix.spec file from postfix.spec.in
#
# It's behaviour depends on the version of Red Hat Linux it is running
# on, but this could be extended to other non-redhat distributions.
# 
# The following external variables if set to 1 affect the behaviour
#
# POSTFIX_REDHAT_MYSQL	include support for RedHat's mysql packages
# POSTFIX_MYSQL		include support for MySQL's  MySQL packages
# POSTFIX_LDAP		include support for openldap packages
# POSTFIX_PCRE		include support for pcre maps
# POSTFIX_SASL		include support for SASL
# POSTFIX_TLS		include support for TLS
# POSTFIX_SMTPD_MULTILINE_GREETING
#			include support for multitline SMTP banner
#
# Red Hat Linux 7.x (at the moment) specific requirements
# (This is detected automatically when you rebuild the spec file)
#
# REQUIRES_DB3		add db3 package to requires list
# REQUIRES_INIT_D	add /etc/init.d/ to requires list
#
# To rebuild the spec file, set the appropriate environment
# variables and do the following:
#
# cd `rpm --eval '%{_sourcedir}'`
# export POSTFIX_MYSQL=1	# for example
# sh make-postfix.spec
# cd `rpm --eval '%{_specdir}'`
# rpm -ba postfix.spec

SUFFIX=
REQUIRES_DB3=
REQUIRES_INIT_D=

# Determine the distribution
DISTRIBUTION=`rpm -qa | grep -- -release | egrep '(redhat-|mandrake-)'`
[ -z "$DISTRIBUTION" ] && DISTRIBUTION='Unknown Distribution'

# Ensure only one of POSTFIX_MYSQL and POSTFIX_REDHAT_MYSQL are defined
[ -n "$POSTFIX_MYSQL" ] && \
[ -n "$POSTFIX_REDHAT_MYSQL" ] && {
    cat <<EOF
Postfix MySQL support
---------------------

There are MySQL packages available from two different sources built with
different package names.  According to the MySQL package you are using
choose to set _ONE_ of the following environment variables accordingly:

POSTFIX_MYSQL = 1	# MySQL packages named MySQL... from www.mysql.com
POSTFIX_REDHAT_MYSQL = 1# MySQL packages named mysql... from RedHat (7+)

Please set the appropriate value and rerun make-postfix.spec again
EOF
    exit 1
}

# RedHat 6.2 and later include LDAP support, earlier versions don't
# For this reason LDAP support is not compiled by default

echo ""
echo "Creating Postfix spec file: `rpm --eval '%{_specdir}'`/postfix.spec"

if [ "$POSTFIX_LDAP" = 1 ]; then
    echo "  adding LDAP  support to spec file"
    SUFFIX="${SUFFIX}+ldap"
fi
if [ "$POSTFIX_PCRE" = 1 ]; then
    echo "  adding PCRE  support to spec file"
    SUFFIX="${SUFFIX}+pcre"
fi
if [ "$POSTFIX_MYSQL" = 1 ]; then
    POSTFIX_REDHAT_MYSQL=0
    echo "  adding MySQL support (www.mysql.com MySQL* packages) to spec file"
    SUFFIX="${SUFFIX}+MySQL"
fi
if [ "$POSTFIX_REDHAT_MYSQL" = 1 ]; then
    POSTFIX_MYSQL=0
    echo "  adding MySQL support (RedHat mysql* packages) to spec file"
    SUFFIX="${SUFFIX}+mysql"
fi
if [ "$POSTFIX_SASL" = 1 ]; then
    echo "  adding SASL  support to spec file"
    SUFFIX="${SUFFIX}+sasl"
fi
if [ "$POSTFIX_TLS" = 1 ]; then
    echo "  adding TLS support to spec file"
    SUFFIX="${SUFFIX}+tls"
fi

# Determine the correct db files to use. RedHat 7 requires db3
if [ `rpm -q redhat-release >/dev/null 2>&1; echo $?` = 0 ]; then
    A=`rpm -q redhat-release | grep -q 7; echo $?`
    if [ "$A" = 0 ]; then
	REQUIRES_INIT_D=1
        REQUIRES_DB3=1
    fi
    # check for RedHat 6 and change SUFFIX to avoid package name conflicts
    A=`rpm -q redhat-release | grep -q 6; echo $?`
    if [ "$A" = 0 ]; then
        SUFFIX="rh6x${SUFFIX}"
    fi
fi

# ensure if undefined the value is 0

[ -z "$REQUIRES_DB3" ]			&& REQUIRES_DB3=0
[ -z "$REQUIRES_INIT_D" ]		&& REQUIRES_INIT_D=0
[ -z "$POSTFIX_LDAP" ]			&& POSTFIX_LDAP=0
[ -z "$POSTFIX_MYSQL" ]			&& POSTFIX_MYSQL=0
[ -z "$POSTFIX_REDHAT_MYSQL" ]		&& POSTFIX_REDHAT_MYSQL=0
[ -z "$POSTFIX_PCRE" ]			&& POSTFIX_PCRE=0
[ -z "$POSTFIX_SASL" ]			&& POSTFIX_SASL=0
[ -z "$POSTFIX_TLS" ]			&& POSTFIX_TLS=0
[ -z "$POSTFIX_SMTPD_MULTILINE_GREETING" ] && POSTFIX_SMTPD_MULTILINE_GREETING=0

# Remove leading '+' from package suffix (if exists)
SUFFIX=`echo "${SUFFIX}" | sed -e 's;^\+;;'`

cat > `rpm --eval '%{_specdir}'`/postfix.spec <<EOF
##############################################################################
#
# W A R N I N G -- DO NOT EDIT THIS FILE -- W A R N I N G
#
# It is generated automatically from postfix.spec.in in the SOURCES directory.
#
# See make-postfix.spec for instructions on rebuilding on a different
# distribution or with different options.
#
# W A R N I N G -- DO NOT EDIT THIS FILE -- W A R N I N G
#
EOF
sed "
s!__REQUIRES_DB3__!$REQUIRES_DB3!g
s!__REQUIRES_INIT_D__!$REQUIRES_INIT_D!g
s!__DISTRIBUTION__!$DISTRIBUTION!g

s!__SMTPD_MULTILINE_GREETING__!$POSTFIX_SMTPD_MULTILINE_GREETING!g

s!__SUFFIX__!$SUFFIX!g

s!__LDAP__!$POSTFIX_LDAP!g
s!__MYSQL__!$POSTFIX_MYSQL!g
s!__REDHAT_MYSQL__!$POSTFIX_REDHAT_MYSQL!g
s!__PCRE__!$POSTFIX_PCRE!g
s!__SASL__!$POSTFIX_SASL!g
s!__TLS__!$POSTFIX_TLS!g
" postfix.spec.in >> `rpm --eval '%{_specdir}'`/postfix.spec

# end of make-postfix.spec
